W_stat: Wilcoxon Sign Rank Test Statistic Exact Distribution
Description
This function allows the user to find the probability
values from the exact distribution of W, Bickel and Doksum(1973).
The exact P(W=x), P(W<=x), P(W>=x) values is found via an exhaustive enumeration
of the possible permutations of data with size n.
Usage
W_stat(n , test_stat, side = c('geq','leq','eq'))
Arguments
n
Size of data or Number of observations
test_stat
The x value specified in P(W=x), P(W<=x), P(W>=x)
side
The tails of exact probability the user wants to compute e.g.
'eq' = P(W=x), 'leq' = P(W<=x), 'geq' = 'P(W>=x)